@@ -127,7 +127,7 @@ class Installer(object):
     def create_package(self):
         from ..utils import chdir
         with chdir(os.path.dirname(self._buildout_path)):
-            execute_assert_success([os.path.join('bin', 'buildout'), '-v', '-s' ,'install', 'pack'])
+            execute_assert_success([os.path.join('bin', 'buildout'), '-v', 'install', 'pack'])
 
     def is_product_installed(self):
         raise NotImplementedError()
@@ -194,7 +194,7 @@ class RpmInstaller(Installer):
         if not with_custom_actions:
             env['NO_CUSTOM_ACTIONS'] = '1'
         with prevent_access_to_pypi_servers(), prevent_access_to_gcc():
-            execute_assert_success(['rpm', '-i', self.get_package()], env=env)
+            execute_assert_success(['rpm', '-Uvh', self.get_package()], env=env)
 
     def uninstall_package(self, with_custom_actions=True):
         env = os.environ.copy()
