@@ -11,7 +11,7 @@ INSTALLDIR = os.path.abspath(os.path.join(os.path.dirname(__file__), #scripts
                                           os.path.pardir, #src
                                           os.path.pardir))
 
-def main(argv=argv):
+def hello(argv=argv):
     print('hello world')
 
 def _write_file(name):
@@ -24,3 +24,5 @@ def post_install(argv=argv):
 def pre_uninstall(argv=argv):
     _write_file(os.path.join(INSTALLDIR, os.path.pardir, 'pre_uninstall'))
 
+def sample(argv=argv):
+    raw_input('sample, hit enter to exit')
